@@ -1,5 +1,5 @@
 package JSONAPI::Document;
-$JSONAPI::Document::VERSION = '1.0';
+$JSONAPI::Document::VERSION = '1.1';
 # ABSTRACT: Turn DBIx results into JSON API documents.
 
 use Moo;
@@ -27,17 +27,24 @@ has api_url => (
     required => 1,
 );
 
-has chi => (
+has data_dir => (
     is => 'ro',
-    default => sub {
-        return CHI->new(driver => 'Memory', global => 1);
-    }
+    required => 1,
+);
+
+has chi => (
+    is => 'lazy',
 );
 
 has segmenter => (
     is => 'lazy',
 );
 
+sub _build_chi {
+    my ($self) = @_;
+    return CHI->new(driver => 'File', root_dir => $self->data_dir);
+}
+
 sub _build_segmenter {
     return Lingua::EN::Segment->new;
 }
@@ -244,7 +251,7 @@ JSONAPI::Document - Turn DBIx results into JSON API documents.
 
 =head1 VERSION
 
-version 1.0
+version 1.1
 
 =head1 SYNOPSIS
 
@@ -284,6 +291,11 @@ while keeping relationship names intact (i.e. an 'author' relationship will stil
 
 =head1 ATTRIBUTES
 
+=head2 data_dir
+
+Required; Directory string where this module can store computed document type strings. This should be
+a directory that's ignored by your VCS.
+
 =head2 api_url
 
 Required; An absolute URL pointing to your servers JSON API namespace.
@@ -358,8 +370,8 @@ View the resource document specification L<here|http://jsonapi.org/format/#docum
 
 Uses L<Lingua::EN::Segment|metacpan.org/pod/Lingua::EN::Segment> to set the appropriate type of the
 document. This is a bit expensive, but it ensures that your schema results source name gets hyphenated
-appropriately when converted into its plural form. The resulting type is cached eternally into memory
-(sorry) to minimize the need to re-compute the document type.
+appropriately when converted into its plural form. The resulting type is cached into the C<data_dir>
+to minimize the need to re-compute the document type.
 
 The following options can be given:
 
